import{_ as p}from"./BiXAZkt9.js";import{_ as s,a}from"./CRjpF7qy.js";import{h as i,v as _,o as c,w as t,b as o}from"./BzhixHsn.js";import"./BYr6U6oc.js";import"./CawQPbYo.js";import"./Dx78NuNM.js";import"./C56gk0qC.js";import"./BmCC6msl.js";import"./EdM3CJ8e.js";import"./D0pu0OPX.js";import"./DkVjT0nP.js";import"./BdE42Imj.js";import"./C8B8ONuC.js";import"./DlAUqK2U.js";import"./Le8goM6p.js";import"./C9XbPd6k.js";import"./CHPRih2d.js";import"./D01W4VS-.js";import"./DU0NpF9R.js";import"./B9I6JWJy.js";const A=i({__name:"test-md",setup(d){const m={id:1,message_type:"user",content:String.raw`
Test message with **markdown**!
 `};return(f,u)=>{const r=p,e=s,n=a;return c(),_(n,null,{default:t(()=>[o(e,null,{default:t(()=>[o(r,{message:m})]),_:1})]),_:1})}}});export{A as default};
