import{_ as n,a as s}from"./CRjpF7qy.js";import{_ as c}from"./DlAUqK2U.js";import{v as r,o as _,w as e,b as f,x as d}from"./BzhixHsn.js";const l={};function m(t,i){const a=n,o=s;return _(),r(o,null,{default:e(()=>[f(a,{class:"legal-content"},{default:e(()=>[d(t.$slots,"default",{},void 0,!0)]),_:3})]),_:3})}const C=c(l,[["render",m],["__scopeId","data-v-d613ff55"]]);export{C as default};
