import{h as o,af as f,v as n,o as d,w as p,x as u,ad as i,g as t,ae as c,ai as _,N as m}from"./BzhixHsn.js";var b=o({__name:"Label",props:{for:{type:String,required:!1},asChild:{type:Boolean,required:!1},as:{type:null,required:!1,default:"label"}},setup(r){const e=r;return f(),(l,a)=>(d(),n(t(c),i(e,{onMousedown:a[0]||(a[0]=s=>{!s.defaultPrevented&&s.detail>1&&s.preventDefault()})}),{default:p(()=>[u(l.$slots,"default")]),_:3},16))}}),g=b;const y=o({__name:"Label",props:{for:{},asChild:{type:Boolean},as:{},class:{}},setup(r){const e=r,l=_(e,"class");return(a,s)=>(d(),n(t(g),i({"data-slot":"label"},t(l),{class:t(m)("flex items-center gap-2 text-sm leading-none font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50",e.class)}),{default:p(()=>[u(a.$slots,"default")]),_:3},16,["class"]))}});export{y as _};
