import{h as r,aP as n,$ as d,a0 as u,g as s,o as c,c as m,y as p,N as f,X as x}from"./BzhixHsn.js";const V=r({__name:"Textarea",props:{class:{},defaultValue:{},modelValue:{}},emits:["update:modelValue"],setup(l,{emit:i}){const e=l,a=n(e,"modelValue",i,{passive:!0,defaultValue:e.defaultValue});return(v,t)=>d((c(),m("textarea",{"onUpdate:modelValue":t[0]||(t[0]=o=>x(a)?a.value=o:null),"data-slot":"textarea",class:p(s(f)("border-input placeholder:text-muted-foreground focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive dark:bg-input/30 flex field-sizing-content min-h-16 w-full rounded-md border bg-transparent px-3 py-2 text-base shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 md:text-sm",e.class))},null,2)),[[u,s(a)]])}});export{V as _};
