<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <title>Email Verification Request</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  </head>
  <body
    style="
      margin: 0;
      padding: 0;
      background-color: #f3f4f6;
      font-family: Arial, sans-serif;
      color: #333;
    "
  >
    <div
      style="
        max-width: 600px;
        margin: 0 auto;
        background-color: #fff;
        border-radius: 8px;
        overflow: hidden;
        box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
      "
    >
      <div style="background-color: #3b82f6; padding: 20px; text-align: center">
        <h1 style="font-size: 24px; color: #ffffff; margin: 0">
          Email Verification Request
        </h1>
      </div>

      <div style="padding: 30px; text-align: center">
        <!-- Logo (inline) -->
        <!-- <img
          src="cid:company_logo"
          alt="Logo"
          style="max-width: 120px; margin-bottom: 20px"
        /> -->

        <p style="margin:0 0 15px;">
          Hello {{ user.email }},
        </p>
        <p style="margin:0 0 20px;">
          Thank you for signing up! To complete your registration, please verify your email by clicking the button below.
        </p>
        <p style="margin:0 0 20px; text-align:center;">
          <a
            href="{{ verify_link }}"
            style="background-color:#1a73e8; color:#ffffff; padding:12px 24px; text-decoration:none; border-radius:4px; display:inline-block; font-weight:bold;"
          >
            Verify Now
          </a>
        </p>
        <p style="margin:0;">
          If you did not sign up with us, simply ignore this message.
        </p>
      </div>
    </div>
  </body>
</html>
