import{h as d,aT as x,v as p,o as r,g as a,aU as h,ad as u,w as n,x as c,ai as _,aV as w,N as f,aW as B,b as g,aX as b,aY as v,a as $,a3 as C,aZ as D,a_ as P,c as O,y as k,a$ as z}from"./BzhixHsn.js";const N=d({__name:"Dialog",props:{open:{type:Boolean},defaultOpen:{type:Boolean},modal:{type:Boolean}},emits:["update:open"],setup(s,{emit:e}){const l=x(s,e);return(i,m)=>(r(),p(a(h),u({"data-slot":"dialog"},a(l)),{default:n(()=>[c(i.$slots,"default")]),_:3},16))}}),F=d({__name:"DialogOverlay",props:{forceMount:{type:Boolean},asChild:{type:Boolean},as:{},class:{}},setup(s){const e=s,t=_(e,"class");return(o,l)=>(r(),p(a(w),u({"data-slot":"dialog-overlay"},a(t),{class:a(f)("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/80",e.class)}),{default:n(()=>[c(o.$slots,"default")]),_:3},16,["class"]))}}),T=d({__name:"DialogContent",props:{forceMount:{type:Boolean},disableOutsidePointerEvents:{type:Boolean},asChild:{type:Boolean},as:{},class:{}},emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","openAutoFocus","closeAutoFocus"],setup(s,{emit:e}){const t=s,o=e,l=_(t,"class"),i=x(l,o);return(m,y)=>(r(),p(a(B),null,{default:n(()=>[g(F),g(a(b),u({"data-slot":"dialog-content"},a(i),{class:a(f)("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 fixed top-[50%] left-[50%] z-50 grid w-full max-w-[calc(100%-2rem)] translate-x-[-50%] translate-y-[-50%] gap-4 rounded-lg border p-6 shadow-lg duration-200 sm:max-w-lg",t.class)}),{default:n(()=>[c(m.$slots,"default"),g(a(v),{class:"ring-offset-background focus:ring-ring data-[state=open]:bg-accent data-[state=open]:text-muted-foreground absolute top-4 right-4 rounded-xs opacity-70 transition-opacity hover:opacity-100 focus:ring-2 focus:ring-offset-2 focus:outline-hidden disabled:pointer-events-none [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4"},{default:n(()=>[g(a(C)),y[0]||(y[0]=$("span",{class:"sr-only"},"Close",-1))]),_:1})]),_:3},16,["class"])]),_:3}))}}),V=d({__name:"DialogDescription",props:{asChild:{type:Boolean},as:{},class:{}},setup(s){const e=s,t=_(e,"class"),o=D(t);return(l,i)=>(r(),p(a(P),u({"data-slot":"dialog-description"},a(o),{class:a(f)("text-muted-foreground text-sm",e.class)}),{default:n(()=>[c(l.$slots,"default")]),_:3},16,["class"]))}}),A=d({__name:"DialogHeader",props:{class:{}},setup(s){const e=s;return(t,o)=>(r(),O("div",{"data-slot":"dialog-header",class:k(a(f)("flex flex-col gap-2 text-center sm:text-left",e.class))},[c(t.$slots,"default")],2))}}),M=d({__name:"DialogTitle",props:{asChild:{type:Boolean},as:{},class:{}},setup(s){const e=s,t=_(e,"class"),o=D(t);return(l,i)=>(r(),p(a(z),u({"data-slot":"dialog-title"},a(o),{class:a(f)("text-lg leading-none font-semibold",e.class)}),{default:n(()=>[c(l.$slots,"default")]),_:3},16,["class"]))}});export{T as _,A as a,M as b,V as c,N as d};
