import{_ as u}from"./lcKie01k.js";import{_ as d,q as f}from"./CJJwG8jL.js";import{e as h,f as x,c,g as o,o as _,a,b as l,t as m}from"./BzhixHsn.js";import{u as y}from"./BmLyE0U0.js";import"./CMS48I6h.js";const v={key:0},C={class:"text-h6"},k={key:1,class:"py-10 text-center"},w={class:"text-gray-500"},N={__name:"terms",async setup(b){let t,n;const{locale:e}=h(),{data:s}=([t,n]=x(()=>y(`terms-${e.value}`,()=>f("content").path(`/${e.value.toLowerCase()}/terms`).first(),{watch:[e]})),t=await t,n(),t);return(g,r)=>{const i=u,p=d;return o(s)?(_(),c("div",v,[a("h1",C,m(o(s).title),1),l(i,{class:"mt-3 mb-5"}),l(p,{value:o(s)},null,8,["value"])])):(_(),c("div",k,[r[0]||(r[0]=a("h1",{class:"text-xl font-bold"},"Document not found",-1)),a("p",w,"Could not find terms for locale: "+m(o(e)),1)]))}}};export{N as default};
