import{T as r}from"./CCA1r4XF.js";import{h as t,v as s,o as n,w as l,x as i,aC as p,aD as d,g as u}from"./BzhixHsn.js";const _=t({__name:"TooltipProvider",props:{delayDuration:{default:0},skipDelayDuration:{},disableHoverableContent:{type:Boolean},disableClosingTrigger:{type:Boolean},disabled:{type:Boolean},ignoreNonKeyboardFocus:{type:Boolean}},setup(e){const o=e;return(a,c)=>(n(),s(u(r),p(d(o)),{default:l(()=>[i(a.$slots,"default")]),_:3},16))}});export{_};
