import{h as t,c,o,y as n,x as l,g as r,N as u,b as m}from"./BzhixHsn.js";import{C as d}from"./DhvzP0AS.js";const b=t({__name:"Breadcrumb",props:{class:{}},setup(s){const a=s;return(e,p)=>(o(),c("nav",{"aria-label":"breadcrumb","data-slot":"breadcrumb",class:n(a.class)},[l(e.$slots,"default")],2))}}),f=t({__name:"BreadcrumbItem",props:{class:{}},setup(s){const a=s;return(e,p)=>(o(),c("li",{"data-slot":"breadcrumb-item",class:n(r(u)("inline-flex items-center gap-1.5",a.class))},[l(e.$slots,"default")],2))}}),g=t({__name:"BreadcrumbList",props:{class:{}},setup(s){const a=s;return(e,p)=>(o(),c("ol",{"data-slot":"breadcrumb-list",class:n(r(u)("text-muted-foreground flex flex-wrap items-center gap-1.5 text-sm break-words sm:gap-2.5",a.class))},[l(e.$slots,"default")],2))}}),h=t({__name:"BreadcrumbPage",props:{class:{}},setup(s){const a=s;return(e,p)=>(o(),c("span",{"data-slot":"breadcrumb-page",role:"link","aria-disabled":"true","aria-current":"page",class:n(r(u)("text-foreground font-normal",a.class))},[l(e.$slots,"default")],2))}}),$=t({__name:"BreadcrumbSeparator",props:{class:{}},setup(s){const a=s;return(e,p)=>(o(),c("li",{"data-slot":"breadcrumb-separator",role:"presentation","aria-hidden":"true",class:n(r(u)("[&>svg]:size-3.5",a.class))},[l(e.$slots,"default",{},()=>[m(r(d))])],2))}});export{b as _,g as a,f as b,$ as c,h as d};
