import{h as o,v as r,o as l,w as n,x as c,y as i,g as s,N as d,ae as u}from"./BzhixHsn.js";const h=o({__name:"BreadcrumbLink",props:{asChild:{type:Boolean},as:{default:"a"},class:{}},setup(a){const e=a;return(t,m)=>(l(),r(s(u),{"data-slot":"breadcrumb-link",as:a.as,"as-child":a.asChild,class:i(s(d)("hover:text-foreground transition-colors",e.class))},{default:n(()=>[c(t.$slots,"default")]),_:3},8,["as","as-child","class"]))}});export{h as _};
