import{h as i,ai as n,v as o,o as d,w as c,x as v,ad as l,g as e,N as u,ae as g,bE as b}from"./BzhixHsn.js";const x=i({__name:"Badge",props:{asChild:{type:Boolean},as:{},variant:{},class:{}},setup(r){const a=r,t=n(a,"class");return(s,p)=>(d(),o(e(g),l({"data-slot":"badge",class:e(u)(e(f)({variant:r.variant}),a.class)},e(t)),{default:c(()=>[v(s.$slots,"default")]),_:3},16,["class"]))}}),f=b("focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive inline-flex w-fit shrink-0 items-center justify-center gap-1.5 overflow-hidden rounded-full border px-3 py-1 text-xs font-medium whitespace-nowrap shadow-xs transition-[color,box-shadow,border] focus-visible:ring-[3px] [&>svg]:pointer-events-none [&>svg]:size-3.5",{variants:{variant:{default:"bg-primary text-primary-foreground [a&]:hover:bg-primary/90 border-transparent",secondary:"bg-secondary text-secondary-foreground [a&]:hover:bg-secondary/90 border-transparent",destructive:"bg-destructive [a&]:hover:bg-destructive/90 focus-visible:ring-destructive/20 dark:focus-visible:ring-destructive/40 dark:bg-destructive/60 border-transparent text-white",outline:"text-foreground [a&]:hover:bg-accent [a&]:hover:text-accent-foreground"}},defaultVariants:{variant:"default"}});export{x as _};
