import{h as l,bI as c,af as d,ab as f,H as v,v as s,o as n,w as u,x as i,ad as g,g as a,ae as m,aC as C,aD as h}from"./BzhixHsn.js";var y=l({__name:"DialogTrigger",props:{asChild:{type:Boolean,required:!1},as:{type:null,required:!1,default:"button"}},setup(t){const r=t,e=c(),{forwardRef:o,currentElement:_}=d();return e.contentId||=f(void 0,"reka-dialog-content"),v(()=>{e.triggerElement.value=_.value}),(p,b)=>(n(),s(a(m),g(r,{ref:a(o),type:p.as==="button"?"button":void 0,"aria-haspopup":"dialog","aria-expanded":a(e).open.value||!1,"aria-controls":a(e).open.value?a(e).contentId:void 0,"data-state":a(e).open.value?"open":"closed",onClick:a(e).onOpenToggle}),{default:u(()=>[i(p.$slots,"default")]),_:3},16,["type","aria-expanded","aria-controls","data-state","onClick"]))}}),D=y,T=l({__name:"AlertDialogTrigger",props:{asChild:{type:Boolean,required:!1},as:{type:null,required:!1,default:"button"}},setup(t){const r=t;return d(),(e,o)=>(n(),s(a(D),C(h(r)),{default:u(()=>[i(e.$slots,"default")]),_:3},16))}}),x=T;const B=l({__name:"AlertDialogTrigger",props:{asChild:{type:Boolean},as:{}},setup(t){const r=t;return(e,o)=>(n(),s(a(x),g({"data-slot":"alert-dialog-trigger"},r),{default:u(()=>[i(e.$slots,"default")]),_:3},16))}});export{B as _};
