import{h as l,af as p,v as r,o as d,w as i,x as n,g as a,ae as u,ad as c}from"./BzhixHsn.js";import{i as _}from"./BYr6U6oc.js";var b=l({__name:"CollapsibleTrigger",props:{asChild:{type:Boolean,required:!1},as:{type:null,required:!1,default:"button"}},setup(s){const o=s;p();const e=_();return(t,g)=>(d(),r(a(u),{type:t.as==="button"?"button":void 0,as:t.as,"as-child":o.asChild,"aria-controls":a(e).contentId,"aria-expanded":a(e).open.value,"data-state":a(e).open.value?"open":"closed","data-disabled":a(e).disabled?.value?"":void 0,disabled:a(e).disabled?.value,onClick:a(e).onOpenToggle},{default:i(()=>[n(t.$slots,"default")]),_:3},8,["type","as","as-child","aria-controls","aria-expanded","data-state","data-disabled","disabled","onClick"]))}}),f=b;const m=l({__name:"CollapsibleTrigger",props:{asChild:{type:Boolean},as:{}},setup(s){const o=s;return(e,t)=>(d(),r(a(f),c({"data-slot":"collapsible-trigger"},o),{default:i(()=>[n(e.$slots,"default")]),_:3},16))}});export{m as _};
