import{h as r,c as o,o as t,x as c,y as n,g as l,N as d}from"./BzhixHsn.js";const _=r({__name:"Card",props:{class:{}},setup(s){const a=s;return(e,p)=>(t(),o("div",{"data-slot":"card",class:n(l(d)("bg-card text-card-foreground border-border/70 flex flex-col gap-5 rounded-2xl border px-6 py-6 shadow-sm",a.class))},[c(e.$slots,"default")],2))}}),f=r({__name:"CardContent",props:{class:{}},setup(s){const a=s;return(e,p)=>(t(),o("div",{"data-slot":"card-content",class:n(l(d)("px-6",a.class))},[c(e.$slots,"default")],2))}});export{f as _,_ as a};
