import{c as s,I as o,g as n,o as a,d as e,a as r}from"./BzhixHsn.js";const c={key:0},i={__name:"ProseScript",props:{src:{type:String,default:""}},setup(d){return(p,t)=>n(!1)?(a(),s("div",c,[...t[0]||(t[0]=[e(" Rendering the ",-1),r("code",null,"script",-1),e(" element is dangerous and is disabled by default. Consider implementing your own ",-1),r("code",null,"ProseScript",-1),e(" element to have control over script rendering. ",-1)])])):o("",!0)}},u=Object.assign(i,{__name:"ProseScript"});export{u as default};
