import{e as a,k as c,g as m}from"./BzhixHsn.js";function l(n,p){const{locale:o}=a(),r=o.value;return c(()=>{const e=m(n);if(!e)return e;const t=e.translations?.[r]||{};return{...e,name:t.name||e.name,description:t.description||e.description,system_prompt:t.system_prompt||e.system_prompt}})}function u(n,p){const{locale:o}=a(),r=o.value;return c(()=>m(n).map(t=>{const s=t.translations?.[r]||{};return{...t,name:s.name||t.name,description:s.description||t.description,system_prompt:s.system_prompt||t.system_prompt}}))}export{u as a,l as u};
