@keyframes bounce-f2e41fe3{0%,80%,to{transform:translateY(0)}40%{transform:translateY(-6px)}}.animate-bounce[data-v-f2e41fe3]{animation:bounce-f2e41fe3 1.4s infinite}.markdown-content[data-v-bd4d606f]>:first-child{margin-top:0!important}.markdown-content[data-v-bd4d606f]>:last-child{margin-bottom:0!important}.citation-marker[data-v-bd4d606f]{color:var(--primary);cursor:pointer;font-weight:600;transition:opacity .15s ease}.citation-marker[data-v-bd4d606f]:hover{opacity:.8;text-decoration:underline}.animate-in[data-v-bd4d606f]{animation-fill-mode:both}.markdown-content[data-v-bd4d606f] code:not(pre code){background:hsl(var(--muted));border-radius:.375rem;font-size:.875em;font-weight:500;padding:.125rem .375rem}
