import{s as c,k as d,c as t,o as n,x as r,g as p}from"./BzhixHsn.js";const u=["id"],f=["href"],k={__name:"ProseH6",props:{id:{type:String,required:!1}},setup(a){const e=a,{headings:o}=c().public.mdc,i=d(()=>e.id&&(typeof o?.anchorLinks=="boolean"&&o?.anchorLinks===!0||typeof o?.anchorLinks=="object"&&o?.anchorLinks?.h6));return(s,h)=>(n(),t("h6",{id:e.id},[e.id&&p(i)?(n(),t("a",{key:0,href:`#${e.id}`},[r(s.$slots,"default")],8,f)):r(s.$slots,"default",{key:1})],8,u))}};export{k as default};
