import{h as l,aP as n,$ as d,a0 as u,g as s,o as f,c,y as m,N as p,X as b}from"./BzhixHsn.js";const V=l({__name:"Input",props:{defaultValue:{},modelValue:{},class:{}},emits:["update:modelValue"],setup(r,{emit:a}){const e=r,i=n(e,"modelValue",a,{passive:!0,defaultValue:e.defaultValue});return(v,t)=>d((f(),c("input",{"onUpdate:modelValue":t[0]||(t[0]=o=>b(i)?i.value=o:null),"data-slot":"input",class:m(s(p)("file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input flex h-10 w-full min-w-0 rounded-lg border bg-transparent px-3.5 py-2 text-[15px] shadow-sm transition-[color,box-shadow,border,transform] outline-none file:inline-flex file:h-8 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm","focus-visible:border-ring focus-visible:ring-ring focus-visible:ring-offset-background focus-visible:ring-2 focus-visible:ring-offset-2","aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",e.class))},null,2)),[[u,s(i)]])}});export{V as _};
