import{Q as r}from"./BzhixHsn.js";function u(){return{showSuccess:(n,o)=>{r.success(n,{duration:o?.duration,action:o?.action})},showError:(n,o)=>{r.error(n,{duration:o?.duration,action:o?.action})},showInfo:(n,o)=>{r.info(n,{duration:o?.duration,action:o?.action})},showWarning:(n,o)=>{r.warning(n,{duration:o?.duration,action:o?.action})}}}export{u};
