import{h as t,c as o,o as r,y as n,g as c,N as l,x as p}from"./BzhixHsn.js";const i=t({__name:"CardDescription",props:{class:{}},setup(s){const e=s;return(a,d)=>(r(),o("p",{"data-slot":"card-description",class:n(c(l)("text-muted-foreground text-sm",e.class))},[p(a.$slots,"default")],2))}});export{i as _};
