.grid[data-v-1a216390]{display:grid}.mb-2[data-v-1a216390]{margin-bottom:.5rem}.mb-4[data-v-1a216390]{margin-bottom:1rem}.max-w-520px[data-v-1a216390]{max-width:520px}.min-h-screen[data-v-1a216390]{min-height:100vh}.place-content-center[data-v-1a216390]{place-content:center}.overflow-hidden[data-v-1a216390]{overflow:hidden}.bg-white[data-v-1a216390]{--un-bg-opacity:1;background-color:rgb(255 255 255/var(--un-bg-opacity))}.px-2[data-v-1a216390]{padding-left:.5rem;padding-right:.5rem}.text-center[data-v-1a216390]{text-align:center}.text-\[80px\][data-v-1a216390]{font-size:80px}.text-2xl[data-v-1a216390]{font-size:1.5rem;line-height:2rem}.text-\[\#020420\][data-v-1a216390]{--un-text-opacity:1;color:rgb(2 4 32/var(--un-text-opacity))}.text-\[\#64748B\][data-v-1a216390]{--un-text-opacity:1;color:rgb(100 116 139/var(--un-text-opacity))}.font-semibold[data-v-1a216390]{font-weight:600}.leading-none[data-v-1a216390]{line-height:1}.tracking-wide[data-v-1a216390]{letter-spacing:.025em}.font-sans[data-v-1a216390]{font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji}.tabular-nums[data-v-1a216390]{--un-numeric-spacing:tabular-nums;font-variant-numeric:var(--un-ordinal) var(--un-slashed-zero) var(--un-numeric-figure) var(--un-numeric-spacing) var(--un-numeric-fraction)}.antialiased[data-v-1a216390]{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}@media(prefers-color-scheme:dark){.dark\:bg-\[\#020420\][data-v-1a216390]{--un-bg-opacity:1;background-color:rgb(2 4 32/var(--un-bg-opacity))}.dark\:text-white[data-v-1a216390]{--un-text-opacity:1;color:rgb(255 255 255/var(--un-text-opacity))}}@media(min-width:640px){.sm\:text-\[110px\][data-v-1a216390]{font-size:110px}.sm\:text-3xl[data-v-1a216390]{font-size:1.875rem;line-height:2.25rem}}
