import{h as r,c as t,o,y as n,g as c,N as d,x as l}from"./BzhixHsn.js";const u=r({__name:"CardHeader",props:{class:{}},setup(a){const s=a;return(e,i)=>(o(),t("div",{"data-slot":"card-header",class:n(c(d)("@container/card-header grid auto-rows-min grid-rows-[auto_auto] items-start gap-1.5 px-6 has-data-[slot=card-action]:grid-cols-[1fr_auto] [.border-b]:pb-6",s.class))},[l(e.$slots,"default")],2))}}),_=r({__name:"CardTitle",props:{class:{}},setup(a){const s=a;return(e,i)=>(o(),t("div",{"data-slot":"card-title",class:n(c(d)("leading-none font-semibold",s.class))},[l(e.$slots,"default")],2))}});export{u as _,_ as a};
