import{h as l,k as s,v as u,o as p,w as d,x as c,ad as _,g as o,ae as h,aC as m,aD as y,ai as B,N as S}from"./BzhixHsn.js";var g=l({__name:"BaseSeparator",props:{orientation:{type:String,required:!1,default:"horizontal"},decorative:{type:Boolean,required:!1},asChild:{type:Boolean,required:!1},as:{type:null,required:!1}},setup(e){const a=e,t=["horizontal","vertical"];function n(r){return t.includes(r)}const i=s(()=>n(a.orientation)?a.orientation:"horizontal"),f=s(()=>i.value==="vertical"?a.orientation:void 0),v=s(()=>a.decorative?{role:"none"}:{"aria-orientation":f.value,role:"separator"});return(r,O)=>(p(),u(o(h),_({as:r.as,"as-child":r.asChild,"data-orientation":i.value},v.value),{default:d(()=>[c(r.$slots,"default")]),_:3},16,["as","as-child","data-orientation"]))}}),q=g,z=l({__name:"Separator",props:{orientation:{type:String,required:!1,default:"horizontal"},decorative:{type:Boolean,required:!1},asChild:{type:Boolean,required:!1},as:{type:null,required:!1}},setup(e){const a=e;return(t,n)=>(p(),u(q,m(y(a)),{default:d(()=>[c(t.$slots,"default")]),_:3},16))}}),C=z;const k=l({__name:"Separator",props:{orientation:{default:"horizontal"},decorative:{type:Boolean,default:!0},asChild:{type:Boolean},as:{},class:{}},setup(e){const a=e,t=B(a,"class");return(n,i)=>(p(),u(o(C),_({"data-slot":"separator-root"},o(t),{class:o(S)("bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px",a.class)}),null,16,["class"]))}});export{k as _};
