import{_ as u}from"./lcKie01k.js";import{_ as d,q as f}from"./CJJwG8jL.js";import{e as y,f as v,c as r,g as o,o as _,a as s,b as l,t as i}from"./BzhixHsn.js";import{u as h}from"./BmLyE0U0.js";import"./CMS48I6h.js";const x={key:0},C={class:"text-h6"},k={key:1,class:"py-10 text-center"},w={class:"text-gray-500"},N={__name:"privacy",async setup(b){let t,n;const{locale:e}=y(),{data:a}=([t,n]=v(()=>h(`privacy-${e.value}`,()=>f("content").path(`/${e.value.toLowerCase()}/privacy`).first(),{watch:[e]})),t=await t,n(),t);return(g,c)=>{const p=u,m=d;return o(a)?(_(),r("div",x,[s("h1",C,i(o(a).title),1),l(p,{class:"mt-3 mb-5"}),l(m,{value:o(a)},null,8,["value"])])):(_(),r("div",k,[c[0]||(c[0]=s("h1",{class:"text-xl font-bold"},"Document not found",-1)),s("p",w,"Could not find privacy policy for locale: "+i(o(e)),1)]))}}};export{N as default};
