import{h as t,c as r,o,a as b,y as l,g as c,N as n,x as d}from"./BzhixHsn.js";const u={"data-slot":"table-container",class:"border-border/70 bg-card relative w-full overflow-auto rounded-xl border shadow-sm"},m=t({__name:"Table",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("div",u,[b("table",{"data-slot":"table",class:l(c(n)("w-full caption-bottom align-middle text-sm",s.class))},[d(a.$slots,"default")],2)]))}}),i=t({__name:"TableBody",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("tbody",{"data-slot":"table-body",class:l(c(n)("[&_tr:last-child]:border-0",s.class))},[d(a.$slots,"default")],2))}}),h=t({__name:"TableCell",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("td",{"data-slot":"table-cell",class:l(c(n)("text-foreground px-3 py-3 align-middle text-sm whitespace-nowrap [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",s.class))},[d(a.$slots,"default")],2))}}),f=t({__name:"TableRow",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("tr",{"data-slot":"table-row",class:l(c(n)("hover:bg-muted/60 data-[state=selected]:bg-muted border-border/70 border-b transition-colors last:border-b-0",s.class))},[d(a.$slots,"default")],2))}}),x=t({__name:"TableHead",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("th",{"data-slot":"table-head",class:l(c(n)("text-muted-foreground border-border/70 bg-muted/40 h-12 border-b px-3 text-left align-middle text-[13px] font-semibold tracking-wide whitespace-nowrap [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",s.class))},[d(a.$slots,"default")],2))}}),g=t({__name:"TableHeader",props:{class:{}},setup(e){const s=e;return(a,p)=>(o(),r("thead",{"data-slot":"table-header",class:l(c(n)("[&_tr]:border-b",s.class))},[d(a.$slots,"default")],2))}});export{m as _,g as a,f as b,x as c,i as d,h as e};
