.typewriter-cursor[data-v-e37b7fbf]{animation:blink-e37b7fbf 1s infinite}@keyframes blink-e37b7fbf{0%,50%{opacity:1}51%,to{opacity:0}}.bg-grid-pattern[data-v-e37b7fbf]{background-image:linear-gradient(hsla(0,0%,100%,.1) 1px,transparent 0),linear-gradient(90deg,hsla(0,0%,100%,.1) 1px,transparent 0);background-size:50px 50px}.floating-orb[data-v-e37b7fbf]{animation:float-e37b7fbf 3s ease-in-out infinite;border-radius:50%;filter:blur(60px);position:absolute}.orb-1[data-v-e37b7fbf]{animation-delay:0s;background:linear-gradient(45deg,#718096,#4a5568);height:200px;right:10%;top:20%;width:200px}.orb-2[data-v-e37b7fbf]{animation-delay:2s;background:linear-gradient(45deg,#63b3ed,#4299e1);bottom:30%;height:150px;left:20%;width:150px}.orb-3[data-v-e37b7fbf]{animation-delay:4s;background:linear-gradient(45deg,#68d391,#48bb78);height:100px;right:30%;top:50%;width:100px}@keyframes float-e37b7fbf{0%,to{transform:translateY(0) translate(0)}33%{transform:translateY(-20px) translate(10px)}66%{transform:translateY(10px) translate(-10px)}}
