import{_ as r}from"./DlAUqK2U.js";import{c as o,o as s,x as t}from"./BzhixHsn.js";const n={};function c(e,a){return s(),o("tr",null,[t(e.$slots,"default")])}const f=Object.assign(r(n,[["render",c]]),{__name:"ProseTr"});export{f as default};
