import{c as t,o as l,x as a,y as r}from"./BzhixHsn.js";const o={__name:"ProsePre",props:{code:{type:String,default:""},language:{type:String,default:null},filename:{type:String,default:null},highlights:{type:Array,default:()=>[]},meta:{type:String,default:null},class:{type:String,default:null}},setup(s){return(e,n)=>(l(),t("pre",{class:r(e.$props.class)},[a(e.$slots,"default")],2))}};export{o as default};
