import{s as i,k as d,c as t,o as n,x as r,g as p}from"./BzhixHsn.js";const u=["id"],f=["href"],k={__name:"ProseH1",props:{id:{type:String,required:!1}},setup(a){const o=a,{headings:e}=i().public.mdc,c=d(()=>o.id&&(typeof e?.anchorLinks=="boolean"&&e?.anchorLinks===!0||typeof e?.anchorLinks=="object"&&e?.anchorLinks?.h1));return(s,h)=>(n(),t("h1",{id:o.id},[p(c)?(n(),t("a",{key:0,href:`#${o.id}`},[r(s.$slots,"default")],8,f)):r(s.$slots,"default",{key:1})],8,u))}};export{k as default};
