import{h as f,ap as u,H as i,j as d,aN as h,i as m,c as b,aO as p}from"./BzhixHsn.js";const k=Symbol.for("nuxt:client-only"),y=f({name:"ClientOnly",inheritAttrs:!1,props:["fallback","placeholder","placeholderTag","fallbackTag"],setup(e,{slots:l,attrs:n}){const t=u(!1);i(()=>{t.value=!0});const o=d();return o&&(o._nuxtClientOnly=!0),p(k,!0),()=>{if(t.value){const a=l.default?.();return a&&a.length===1?[h(a[0],n)]:a}const c=l.fallback||l.placeholder;if(c)return m(c);const r=e.fallback||e.placeholder||"",s=e.fallbackTag||e.placeholderTag||"span";return b(s,n,r)}}});export{y as _,k as c};
