import{_ as o}from"./DlAUqK2U.js";import{c as r,o as s,x as t}from"./BzhixHsn.js";const a={};function n(e,c){return s(),r("thead",null,[t(e.$slots,"default")])}const d=Object.assign(o(a,[["render",n]]),{__name:"ProseThead"});export{d as default};
