import{h as v,b0 as b,af as y,E as o,bk as T,ac as _,x as m}from"./BzhixHsn.js";const[q,g]=_("TooltipProvider");var C=v({inheritAttrs:!1,__name:"TooltipProvider",props:{delayDuration:{type:Number,required:!1,default:700},skipDelayDuration:{type:Number,required:!1,default:300},disableHoverableContent:{type:Boolean,required:!1,default:!1},disableClosingTrigger:{type:Boolean,required:!1},disabled:{type:Boolean,required:!1},ignoreNonKeyboardFocus:{type:Boolean,required:!1,default:!1}},setup(r){const t=r,{delayDuration:a,skipDelayDuration:s,disableHoverableContent:i,disableClosingTrigger:l,ignoreNonKeyboardFocus:n,disabled:d}=b(t);y();const e=o(!0),u=o(!1),{start:p,stop:f}=T(()=>{e.value=!0},s,{immediate:!1});return g({isOpenDelayed:e,delayDuration:a,onOpen(){f(),e.value=!1},onClose(){p()},isPointerInTransitRef:u,disableHoverableContent:i,disableClosingTrigger:l,disabled:d,ignoreNonKeyboardFocus:n}),(c,D)=>m(c.$slots,"default")}}),x=C;export{x as T,q as i};
