import{k as i,bM as n,ay as o,s as c,ax as h,v as l,o as p,g as s,a2 as u}from"./BzhixHsn.js";const g="img",f={__name:"ProseImg",props:{src:{type:String,default:""},alt:{type:String,default:""},width:{type:[String,Number],default:void 0},height:{type:[String,Number],default:void 0}},setup(a){const t=a,r=i(()=>{if(t.src?.startsWith("/")&&!t.src.startsWith("//")){const e=n(o(c().app.baseURL));if(e!=="/"&&!t.src.startsWith(e))return h(e,t.src)}return t.src});return(e,d)=>(p(),l(u(s(g)),{src:s(r),alt:t.alt,width:t.width,height:t.height},null,8,["src","alt","width","height"]))}};export{f as default};
