import{h as r,c as l,o as c,y as n,g as e,N as o,x as i,bE as p}from"./BzhixHsn.js";const v=r({__name:"Alert",props:{class:{},variant:{}},setup(t){const a=t;return(s,d)=>(c(),l("div",{"data-slot":"alert",class:n(e(o)(e(u)({variant:t.variant}),a.class)),role:"alert"},[i(s.$slots,"default")],2))}}),m=r({__name:"AlertDescription",props:{class:{}},setup(t){const a=t;return(s,d)=>(c(),l("div",{"data-slot":"alert-description",class:n(e(o)("text-muted-foreground col-start-2 grid justify-items-start gap-1 text-sm [&_p]:leading-relaxed",a.class))},[i(s.$slots,"default")],2))}}),f=r({__name:"AlertTitle",props:{class:{}},setup(t){const a=t;return(s,d)=>(c(),l("div",{"data-slot":"alert-title",class:n(e(o)("col-start-2 line-clamp-1 min-h-4 font-medium tracking-tight",a.class))},[i(s.$slots,"default")],2))}}),u=p("relative grid w-full grid-cols-[0_1fr] items-start gap-y-0.5 rounded-lg border px-4 py-3 text-sm has-[>svg]:grid-cols-[calc(var(--spacing)*4)_1fr] has-[>svg]:gap-x-3 [&>svg]:size-4 [&>svg]:translate-y-0.5 [&>svg]:text-current",{variants:{variant:{default:"bg-card text-card-foreground",destructive:"text-destructive bg-card *:data-[slot=alert-description]:text-destructive/90 [&>svg]:text-current"}},defaultVariants:{variant:"default"}});export{f as _,m as a,v as b};
