import{h as d,af as f,E as p,Z as m,bm as v,v as n,I as _,g as s,o as i,w as u,x as c,ae as y,ai as h,ad as C,N as b}from"./BzhixHsn.js";import{i as k}from"./BSaEE8c4.js";var w=d({__name:"AvatarFallback",props:{delayMs:{type:Number,required:!1},asChild:{type:Boolean,required:!1},as:{type:null,required:!1,default:"span"}},setup(l){const a=l,r=k();f();const t=p(a.delayMs===void 0);return m(e=>{if(a.delayMs&&v){const o=window.setTimeout(()=>{t.value=!0},a.delayMs);e(()=>{window.clearTimeout(o)})}}),(e,o)=>t.value&&s(r).imageLoadingStatus.value!=="loaded"?(i(),n(s(y),{key:0,"as-child":e.asChild,as:e.as},{default:u(()=>[c(e.$slots,"default")]),_:3},8,["as-child","as"])):_("v-if",!0)}}),g=w;const F=d({__name:"AvatarFallback",props:{delayMs:{},asChild:{type:Boolean},as:{},class:{}},setup(l){const a=l,r=h(a,"class");return(t,e)=>(i(),n(s(g),C({"data-slot":"avatar-fallback"},s(r),{class:s(b)("bg-muted flex size-full items-center justify-center rounded-full",a.class)}),{default:u(()=>[c(t.$slots,"default")]),_:3},16,["class"]))}});export{F as _};
