import{_ as g}from"./6PIUWI5X.js";import{h as m,e as b,E as c,B as h,H as _,c as x,o as y,a as t,t as d,g as o,s as w,x as k,bP as C,d as j,O as f}from"./BzhixHsn.js";import{u as I}from"./BLw_G03o.js";import{s as S}from"./D-0Ld2CH.js";import{_ as B}from"./DlAUqK2U.js";const N={class:"grid min-h-svh lg:grid-cols-2"},T={class:"flex flex-col gap-4 p-6 md:p-10"},L={class:"flex justify-center gap-2 md:justify-start"},V={class:"font-bold"},z={class:"flex flex-1 items-center justify-center"},A={class:"w-full max-w-xs"},D={class:"relative hidden overflow-hidden bg-gradient-to-br from-slate-900 via-slate-800 to-gray-900 lg:block lg:flex lg:flex-col"},E={class:"relative z-10 flex flex-1 items-center justify-center"},R={class:"typewriter text-center text-3xl font-bold text-white drop-shadow-lg"},H=m({__name:"auth",setup(K){const{t:u}=b(),v=w(),a=I(),i=c(""),n=u("common.slogan"),r=h(),l=c(0),p=async()=>{if(r.path==="/sign-in"||r.path==="/sign-up"){await f("/sign-in",{replace:!0}),l.value++;return}if(a.isDirty){if(!window.confirm("You have unsaved changes. Leave this page and go to Chat?"))return;a.clearAll()}await f("/chat")};return _(()=>{let s=0;const e=S(()=>{s<n.length?(i.value+=n.charAt(s),s++):clearInterval(e)},150)}),(s,e)=>(y(),x("div",N,[t("div",T,[t("div",L,[t("button",{type:"button",class:"flex items-center gap-2 font-medium transition-opacity hover:opacity-90",onClick:p},[e[0]||(e[0]=t("div",{class:"flex size-10 items-center justify-center rounded-md"},[t("img",{src:g,alt:"Logo"})],-1)),t("span",V,d(o(v).public.appName),1)])]),t("div",z,[t("div",A,[k(s.$slots,"default",{key:o(l)},void 0,!0)])])]),t("div",D,[e[2]||(e[2]=C('<div class="bg-grid-pattern absolute inset-0 opacity-20" data-v-e37b7fbf></div><div class="absolute inset-0" data-v-e37b7fbf><div class="floating-orb orb-1" data-v-e37b7fbf></div><div class="floating-orb orb-2" data-v-e37b7fbf></div><div class="floating-orb orb-3" data-v-e37b7fbf></div></div>',2)),t("div",E,[t("h1",R,[j(d(o(i))+" ",1),e[1]||(e[1]=t("span",{class:"typewriter-cursor"},"|",-1))])])])]))}}),$=B(H,[["__scopeId","data-v-e37b7fbf"]]);export{$ as default};
