import{_ as s}from"./BnGAqGo1.js";import{h as i,e as c,u as p,B as u,k as a,v as m,o as _,g as l}from"./BzhixHsn.js";import"./4isL45Eu.js";import"./Di109XjC.js";import"./hcYt5xb6.js";import"./G5O1m7ek.js";import"./BmLyE0U0.js";import"./CMS48I6h.js";const q=i({__name:"sign-in",setup(d){const{t:e}=c();p({title:e("pageTitle.signIn")});const r=u(),o=a(()=>{const t=r.query.redirect;return typeof t=="string"&&t.length>0?t:void 0});return(t,g)=>{const n=s;return _(),m(n,{scene:"sign-in","redirect-url":l(o)},null,8,["redirect-url"])}}});export{q as default};
