import{a as o,_ as r}from"./BSaEE8c4.js";import{_ as i}from"./DdeO54y7.js";import{h as l,v as m,o as _,w as s,b as t,d as A,t as f,y as p}from"./BzhixHsn.js";const u=l({__name:"AssistantAvatar",props:{assistant:{},class:{}},setup(a){return(v,d)=>{const n=o,e=i,c=r;return _(),m(c,{class:p(a.class)},{default:s(()=>[t(n,{src:a.assistant?.avatar_url||"",alt:a.assistant?.name||""},null,8,["src","alt"]),t(e,null,{default:s(()=>[A(f(a.assistant?.name?.charAt(0)?.toUpperCase()||"?"),1)]),_:1})]),_:1},8,["class"])}}}),b=Object.assign(u,{__name:"AssistantAvatar"});export{b as A};
